<?php

use CRM_Loginsecurity_ExtensionUtil as E;

/**
 * Form controller class
 *
 * @see https://docs.civicrm.org/dev/en/latest/framework/quickform/
 */
class CRM_Loginsecurity_Form_LoginsecurityOtp extends CRM_Core_Form {

  public function buildQuickForm(): void {
    if (!CRM_Loginsecurity_Utils::isOtpNotExpired()) {
      CRM_Utils_System::logout();
      CRM_Utils_System::redirect(CRM_Utils_System::url('civicrm', 'reset=1'));
    }
    CRM_Utils_System::setTitle(E::ts('Login Security: One Time Password'));
    $this->assign('loginsecurity_error', '');
    $this->add('text', 'loginsecurity_otp', E::ts('One Time Password'), ['autocomplete' => 'new-password'], TRUE);
    $this->addButtons([
      [
        'type' => 'submit',
        'name' => E::ts('Submit'),
        'isDefault' => TRUE,
      ],
    ]);
    parent::buildQuickForm();
  }

  public function postProcess(): void {
    $values = $this->exportValues();
    $stored_otp = Civi::contactSettings()->get('loginsecurity_otp');
    if ($stored_otp && $values['loginsecurity_otp'] == $stored_otp) {
      // Set the device as trusted, so that we do not ask for an OTP again
      $contact_id = CRM_Core_Session::getLoggedInContactID();
      $session_id = session_id();
      \Civi\Api4\LoginSecurityDevice::update(FALSE)
        ->addWhere('contact_id', '=', $contact_id)
        ->addWhere('session_id', '=', $session_id)
        ->addValue('is_trusted', 1)
        ->execute();
      // Invalidate the OTP, which will allow the user to login
      Civi::contactSettings()->set('loginsecurity_otp', '');
      CRM_Utils_System::redirect(CRM_Utils_System::url('civicrm/dashboard', 'reset=1'));
    }
    else {
      $this->assign('loginsecurity_error', E::ts('The code you entered is not valid.'));
    }
    parent::postProcess();
  }

}
