<?php

class CRM_Loginsecurity_Utils_Mail {

  /**
   *
   */
  public static function sendNotification($tplParams) {
    if (empty($tplParams['contact_id'])) {
      throw new Exception('Missing contact_id');
    }

    // Fetch the display_name of the user
    // Avoid confusion with display_name, because it might be an admin notification
    $contact = \Civi\Api4\Contact::get(false)
      ->addSelect('display_name')
      ->addSelect('email.email')
      ->setJoin([
        ['Email AS email', FALSE, NULL, ['email.is_primary', '=', 1]],
      ])
      ->addWhere('id', '=', $tplParams['contact_id'])
      ->execute()
      ->first();

    $tplParams['user_display_name'] = $contact['display_name'];

    if (!empty($tplParams['ip_address'])) {
      $tplParams['user_location'] = CRM_Loginsecurity_BAO_LoginSecurityDevice::getGeoIP($tplParams['ip_address']);
    }

    // @todo Localize? or ISO-8601? Having the timezone is useful
    $tplParams['date_last_seen'] = date('Y-m-d H:i:s T');

    // About the site
    $tplParams['civicrm_url'] = CRM_Utils_System::url('civicrm', NULL, TRUE, NULL, FALSE, TRUE);
    $domainValues = CRM_Core_BAO_Domain::getNameAndEmail();

    $sendTemplateParams = [
      'groupName' => 'msg_tpl_workflow_uf',
      'valueName' => $tplParams['valueName'],
      'tplParams' => $tplParams,
      'isTest' => 0,
      'from' => "$domainValues[0] <$domainValues[1]>",
    ];

    if (!empty($tplParams['admin_email'])) {
      $sendTemplateParams['toEmail'] = $tplParams['admin_email'];
    }
    else {
      // Assuming we are sending to the user
      $sendTemplateParams['toName'] = $contact['display_name'];
      $sendTemplateParams['toEmail'] = $contact['email.email'];
    }

    list($sent) = CRM_Core_BAO_MessageTemplate::sendTemplate($sendTemplateParams);
    \Civi::log()->debug('loginsecurity sendTemplate: ' . print_r($sent, 1));
  }

}
