<?php

use CRM_Loginsecurity_ExtensionUtil as E;

return [
  'loginsecurity_notify_users' => [
    'name' => 'loginsecurity_notify_users',
    'type' => 'String',
    'default' => '',
    'html_type' => 'select',
    'html_attributes' => [
      'class' => 'huge',
    ],
    'options' => [
      '' => E::ts('never'),
      'new' => E::ts('Only for new devices or locations'),
      'newotp' => E::ts('Only for new devices or locations - and require a one-time-code sent by email if TFA not set'),
      'always' => E::ts('For every new session'),
      'alwaysotp' => E::ts('For every new session - and require a one-time-code sent by email if TFA not set'),
    ],
    'add' => '1.0',
    'title' => E::ts('User Notifications'),
    'is_domain' => 1,
    'is_contact' => 0,
    'description' => E::ts('Should we send access notifications to users?'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 10,
      ],
    ],
  ],
  'loginsecurity_notify_admins' => [
    'name' => 'loginsecurity_notify_admins',
    'type' => 'String',
    'default' => '',
    'html_type' => 'select',
    'html_attributes' => [
      'class' => 'huge',
    ],
    'options' => [
      '' => E::ts('never'),
      'new' => E::ts('Only for new devices or locations'),
      'always' => E::ts('For every new session'),
    ],
    'add' => '1.0',
    'title' => E::ts('Admin Notifications'),
    'is_domain' => 1,
    'is_contact' => 0,
    'description' => E::ts('Should we send access notifications to administrators?'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 20,
      ],
    ],
  ],
  'loginsecurity_notify_admin_emails' => [
    'name' => 'loginsecurity_notify_admin_emails',
    'type' => 'String',
    'default' => FALSE,
    'html_type' => 'text',
    'html_attributes' => [
      'class' => 'huge',
    ],
    'add' => '1.0',
    'title' => E::ts('Admin Emails'),
    'is_domain' => 1,
    'is_contact' => 0,
    'description' => E::ts('Administrator emails to notify, if enabled. Separate multiple addersses by a comma. Example: alice@example.org,bob@example.org'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 30,
      ],
    ],
  ],
  'loginsecurity_apilog' => [
    'name' => 'loginsecurity_apilog',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'add' => '1.0',
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Log API requests?'),
    'description' => E::ts('By default API access is closed. An administrators must create a key for users who need API access. Depending on how the API is used, the requests can be very frequent, and the verifications done by Login Security might be too intensive.'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 35,
      ],
    ],
  ],
  'loginsecurity_log_petitions' => [
    'name' => 'loginsecurity_log_petitions',
    'type' => 'Boolean',
    'html_type' => 'checkbox',
    'default' => 0,
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Log petition signatures?'),
    'description' => E::ts('When someone signs a Petition, log the IP and fingerprint the browser'),
    'html_attributes' => [],
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 37,
      ],
    ],
  ],
  'loginsecurity_proxy' => [
    'name' => 'loginsecurity_proxy',
    'type' => 'Integer',
    'html_type' => 'radio',
    'default' => 0,
    'options' => [
      0 => E::ts('No'),
      1 => E::ts('Yes'),
    ],
    'add' => '1.0',
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Is CiviCRM behind a proxy?'),
    'description' => E::ts('If CiviCRM hosted behind a proxy, such as CloudFlare or Varnish, this will have an impact on which IP address is logged. However, this must only be enabled if you are behind a proxy, otherwise it allows visitors to fake their IP address. Enabling this also assumes that the firewall is blocking all requests except those from the proxy. If you are not sure, please contact your hosting provider. For more information, see <a %1>issue dev/core#2854</a>.', [1 => 'href="https://lab.civicrm.org/dev/core/-/issues/2854" target="_blank"']),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 40,
      ],
    ],
  ],
  'loginsecurity_notify_export' => [
    'name' => 'loginsecurity_notify_export',
    'type' => 'String',
    'html_type' => 'text',
    'html_attributes' => [
      'class' => 'huge',
    ],
    'default' => '',
    'add' => '1.0',
    'is_domain' => 1,
    'is_contact' => 0,
    'title' => E::ts('Notify when someone exports data?'),
    'description' => E::ts('Send an email notification when someone exports data from CiviCRM.'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 50,
      ],
    ],
  ],
  'loginsecurity_otp' => [
    'name' => 'loginsecurity_otp',
    'type' => 'Int',
    'default' => '',
    'html_type' => 'text',
    'add' => '1.4',
    'title' => E::ts('Contact OTP'),
    'is_domain' => 1,
    'is_contact' => 1,
    'description' => E::ts('One time password sent to users who do not have TFA setup'),
    'settings_pages' => [
      'loginsecurity' => [
        'weight' => 100,
      ],
    ],
  ],
];
